org.openqa.selenium.server Class Hierarchy (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Hierarchy For Package org.openqa.selenium.server

Package Hierarchies:
  All Packages

## Class Hierarchy

- java.lang.Object
  - org.mortbay.http.handler.AbstractHttpHandler (implements org.mortbay.http.HttpHandler)
    - org.openqa.selenium.server.ProxyHandler
    - org.mortbay.http.handler.ResourceHandler
      - org.openqa.selenium.server.SeleniumDriverResourceHandler
      - org.openqa.selenium.server.StaticContentHandler
  - org.openqa.selenium.server.ApplicationRegistry
  - org.openqa.selenium.server.BrowserConfigurationOptions
  - org.openqa.selenium.server.BrowserResponseSequencer
  - org.openqa.selenium.server.BrowserSessionFactory
  - org.openqa.selenium.server.BrowserSessionFactory.BrowserSessionInfo
  - org.openqa.selenium.server.CachedContentTestHandler (implements org.mortbay.http.HttpHandler)
  - org.openqa.selenium.server.ClasspathResourceLocator (implements org.openqa.selenium.server.ResourceLocator)
  - org.openqa.selenium.server.CommandHolder
  - org.openqa.selenium.server.CommandQueue
  - org.openqa.selenium.server.CommandResultHolder
  - org.openqa.selenium.server.DefaultRemoteCommand (implements org.openqa.selenium.server.RemoteCommand)
  - org.openqa.selenium.server.FrameAddress
  - org.openqa.selenium.server.FrameGroupCommandQueueSet
  - org.openqa.selenium.server.FsResourceLocator (implements org.openqa.selenium.server.ResourceLocator)
  - org.openqa.selenium.server.HtmlIdentifier
  - org.openqa.selenium.server.InjectionHelper
  - org.openqa.selenium.server.IOHelper
  - org.openqa.selenium.server.ModifiedIO
  - org.openqa.selenium.server.RemoteControlConfiguration
  - org.mortbay.util.Resource (implements java.io.Serializable)
    - org.openqa.selenium.server.ClassPathResource
    - org.mortbay.util.URLResource
      - org.openqa.selenium.server.FutureFileResource
  - org.openqa.selenium.server.RobotRetriever
  - org.openqa.selenium.server.SeleniumServer
  - org.openqa.selenium.server.SingleEntryAsyncQueue<T>
  - java.lang.Throwable (implements java.io.Serializable)
    - java.lang.Exception
      - org.openqa.selenium.server.RemoteCommandException
        - org.openqa.selenium.server.WindowClosedException
      - java.lang.RuntimeException
        - org.openqa.selenium.server.SeleniumCommandTimedOutException
  - java.util.TimerTask (implements java.lang.Runnable)
    - org.openqa.selenium.server.BrowserSessionFactory.CleanupTask
  - org.openqa.selenium.server.TrustEverythingSSLTrustManager (implements javax.net.ssl.X509TrustManager)

## Interface Hierarchy

- org.openqa.selenium.server.RemoteCommand
- org.openqa.selenium.server.ResourceLocator

## Enum Hierarchy

- java.lang.Object
  - java.lang.Enum<E> (implements java.lang.Comparable<T>, java.io.Serializable)
    - org.openqa.selenium.server.SpecialCommand

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.